@@ -6,9 +6,14 @@ import os.path
 # to use it.
 rabbyt.data_directory = os.path.dirname(__file__)
 
-# Make sure that you allways have a valid OpenGL context before creating a
-# sprite.  This init function will do that for you:
-rabbyt.init_display((640, 480))
+pygame.init()
+
+# Make sure that you allways have an OpenGL window created before loading
+# textures:
+pygame.display.set_mode((640, 480), pygame.OPENGL | pygame.DOUBLEBUF)
+
+rabbyt.set_viewport((640, 480))
+rabbyt.set_default_attribs()
 
 # Creating a sprite is easy.  Just give it an image filename.
 car = rabbyt.Sprite("car.png")
