@@ -5,7 +5,10 @@ import os.path
 rabbyt.data_directory = os.path.dirname(__file__)
 
 
-rabbyt.init_display((640, 480))
+pygame.init()
+pygame.display.set_mode((640, 480), pygame.OPENGL | pygame.DOUBLEBUF)
+rabbyt.set_viewport((640, 480))
+rabbyt.set_default_attribs()
 
 car = rabbyt.Sprite("car.png")
 
@@ -14,10 +17,10 @@ car = rabbyt.Sprite("car.png")
 # done in Pyrex code, so it is practically free.
 
 # Fade the car in after one second.
-car.alpha = rabbyt.lerp(0.0, 1.0, startt=1000, endt=2000)
+car.alpha = rabbyt.lerp(0.0, 1.0, startt=1, endt=2)
 
 # Rotate the car from 0 to 360 over three seconds, then repeat.
-car.rot = rabbyt.lerp(0, 360, dt=3000, extend="repeat")
+car.rot = rabbyt.lerp(0, 360, dt=3, extend="repeat")
 
 while not pygame.event.get(pygame.QUIT):
     rabbyt.clear((1,1,1))
@@ -28,7 +31,7 @@ while not pygame.event.get(pygame.QUIT):
     # high-resolution clock implementaion and 2) you can have complete control
     # over time.  This could be very useful if you want to add a 'pause' feature
     # to you game :)
-    rabbyt.set_time(pygame.time.get_ticks())
+    rabbyt.set_time(pygame.time.get_ticks()/1000.0)
 
     car.render()
 
